<?php

/**
 * zolog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage Zolog
 * @since Zolog 1.0
 */

if (!function_exists('hs_zolog_setup')) :
    function hs_zolog_setup()
    {
        load_theme_textdomain('zolog', get_template_directory() . '/languages');

        add_theme_support('automatic-feed-links');

        add_theme_support('title-tag');

        /**
         * Add post-formats support.
         */
        add_theme_support(
            'post-formats',
            array(
                'link',
                'aside',
                'gallery',
                'image',
                'quote',
                'status',
                'video',
                'audio',
                'chat',
            )
        );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');
        set_post_thumbnail_size(1600, 9999);

        // This theme uses wp_nav_menu() in three location.
        register_nav_menus(
            array(
                'main-menu' => esc_html__('Main Menu', 'zolog'),
                'social-menu' => esc_html__('Social Menu', 'zolog'),
                'bottom-social-menu' => esc_html__('Bottom Social Menu', 'zolog'),
            )
        );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
                'style',
                'script',
                'navigation-widgets',
            )
        );

        // Set up the WordPress core custom background feature.
        add_theme_support(
            'custom-background',
            apply_filters(
                'zolog_custom_background_args',
                array(
                    'default-color' => 'ffffff',
                    'default-image' => '',
                )
            )
        );

        // Add support for responsive embedded content.
        add_theme_support('responsive-embeds');

        // Add support for full and wide align images.
        add_theme_support('align-wide');

        add_image_size('zolog-blog-thumbnail', 600, 400, array('center', 'center'), true);
        add_image_size('zolog-archive-thumbnail', 600, 400, array('center', 'center'), true);
        add_image_size('zolog-search-thumbnail', 600, 400, array('center', 'center'), true);

        // Add support for editor styles.
        add_theme_support('editor-styles');

        $editor_stylesheet_path = 'assets/css/editor-style.css';
        // Enqueue editor styles.
        add_editor_style($editor_stylesheet_path);

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height' => 300,
                'width' => 250,
                'flex-width' => true,
                'flex-height' => true,
                'unlink-homepage-logo' => true,
            )
        );
    }
    add_action('after_setup_theme', 'hs_zolog_setup');
endif;

require get_template_directory() . '/inc/welcome.php';
require get_template_directory() . '/inc/template-functions.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/framework/tgmp/class-tgm-activation.php';

get_template_part('/inc/customize/customize');
get_template_part('/widgets/banner/banner');
get_template_part('/widgets/categoryslider/categoryslider');
get_template_part('/widgets/about-me/about-me');
get_template_part('/widgets/category/category');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function hs_zolog_content_width()
{
    $GLOBALS['content_width'] = apply_filters('zolog_content_width', 1600);
}

add_action('after_setup_theme', 'hs_zolog_content_width', 0);

/**
 * Enqueue scripts and styles.
 */
if (!function_exists('hs_zolog_enqueue_scripts')) {
    function hs_zolog_enqueue_scripts()
    {
        // Theme stylesheet.
        global $wp_scripts;
        wp_enqueue_style('zolog-style', get_stylesheet_uri());

        wp_enqueue_style('zolog-header-theme', esc_url(get_template_directory_uri() . '/assets/css/header/theme-1.css'), array('zolog-style'), null);

        wp_enqueue_style('zolog-content-theme', esc_url(get_template_directory_uri() . '/assets/css/content/theme-1.css'), array('zolog-style'), null);

        wp_enqueue_style('dashicons');

        if (esc_attr(get_theme_mod('zolog_fontawesome_display', 'yes')) == 'yes') {
            wp_enqueue_style('discord', get_template_directory_uri() . '/framework/font-awesome/css/discord.css', array(), '1');
            wp_enqueue_style('fontawesome', get_template_directory_uri() . '/framework/font-awesome/css/font-awesome.min.css', array(), '1');
        }

        wp_enqueue_style('zolog-slick', esc_url(get_template_directory_uri() . '/assets/slick/slick.css'), array('zolog-style'), null);

        wp_enqueue_script('zolog-main-script', get_template_directory_uri() . '/assets/js/custom.js', array('jquery'), '1.0.0', true);
        $banner_values = array(
            'is_rtl' => is_rtl()
        );
        wp_add_inline_script('zolog-main-script', 'var zolog_is_rtl = ' . wp_json_encode($banner_values), 'before');

        wp_enqueue_script('zolog-header-theme', esc_url(get_template_directory_uri() . '/assets/js/header/theme-1.js'), array('zolog-main-script'), '1.0.0', true);

        wp_enqueue_script('zolog-slick-script', get_template_directory_uri() . '/assets/slick/slick.min.js', array('jquery'), '1.0.0', true);

        if (esc_attr(get_theme_mod('zolog_slider_display', 'yes')) == 'yes') {
            wp_enqueue_style('zolog-home-slider', esc_url(get_template_directory_uri() . '/assets/css/slider.css'), array('zolog-slick'), null);
            wp_enqueue_script('zolog-home-slider-script', esc_url(get_template_directory_uri() . '/assets/js/slider.js'), array('zolog-slick-script'), '1.0.0', true);
        }

        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        // Register the IE11 polyfill file.
        wp_register_script(
            'zolog-ie11-polyfills-asset',
            get_template_directory_uri() . '/assets/js/polyfills.js',
            array(),
            wp_get_theme()->get('Version'),
            true
        );

        // Register the IE11 polyfill loader.
        wp_register_script(
            'zolog-ie11-polyfills',
            null,
            array(),
            wp_get_theme()->get('Version'),
            true
        );

        wp_add_inline_script(
            'zolog-ie11-polyfills',
            wp_get_script_polyfill(
                $wp_scripts,
                array(
                    'Element.prototype.matches && Element.prototype.closest && window.NodeList && NodeList.prototype.forEach' => 'hs-zolog-ie11-polyfills-asset',
                )
            )
        );

        // Responsive embeds script.
        wp_enqueue_script(
            'zolog-responsive-embeds-script',
            get_template_directory_uri() . '/assets/js/responsive-embeds.js',
            array('zolog-ie11-polyfills'),
            wp_get_theme()->get('Version'),
            true
        );
    }

    add_action('wp_enqueue_scripts', 'hs_zolog_enqueue_scripts');
}

function hs_zolog_admin_style()
{
    wp_enqueue_style('zolog-admin-css', get_template_directory_uri() . '/assets/css/admin.css', array(), '1');
}
add_action('admin_enqueue_scripts', 'hs_zolog_admin_style');

function zolog_customizer_control_toggle()
{
    wp_enqueue_script('zolog-customize-controls-toggle', get_template_directory_uri() . '/inc/customize/assets/customize-controls-toggle.js', array('jquery', 'customize-preview'), '1.30', true);
}
add_action('customize_controls_enqueue_scripts', 'zolog_customizer_control_toggle');

if (!function_exists('hs_zolog_skip_link_focus_fix')) {
    /**
     * Fix skip link focus in IE11.
     *
     * This does not enqueue the script because it is tiny and because it is only for IE11,
     * thus it does not warrant having an entire dedicated blocking script being loaded.
     *
     * @link https://git.io/vWdr2
     */
    function hs_zolog_skip_link_focus_fix()
    {

        // If SCRIPT_DEBUG is defined and true, print the unminified file.
        if (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) {
            echo '<script>';
            include get_template_directory() . '/assets/js/skip-link-focus-fix.js';
            echo '</script>';
        }

        // The following is minified via `npx terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
?>
        <script>
            /(trident|msie)/i.test(navigator.userAgent) && document.getElementById && window.addEventListener && window.addEventListener("hashchange", (function() {
                var t, e = location.hash.substring(1);
                /^[A-z0-9_-]+$/.test(e) && (t = document.getElementById(e)) && (/^(?:a|select|input|button|textarea)$/i.test(t.tagName) || (t.tabIndex = -1), t.focus())
            }), !1);
        </script>
    <?php
    }

    add_action('wp_print_footer_scripts', 'hs_zolog_skip_link_focus_fix');
}

/**
 * Add "is-IE" class to body if the user is on Internet Explorer.
 */
function hs_zolog_add_ie_class()
{
    ?>
    <script>
        if (-1 !== navigator.userAgent.indexOf('MSIE') || -1 !== navigator.appVersion.indexOf('Trident/')) {
            document.body.classList.add('is-IE');
        }
    </script>
<?php
}

add_action('wp_footer', 'hs_zolog_add_ie_class');

function hs_zolog_custom_add_google_fonts()
{
    $google_font_text = get_theme_mod('zolog_google_font_url');
    $google_font_header = get_theme_mod('zolog_google_font_header_url');
    if (!empty($google_font_text)) {
        wp_enqueue_style('custom-google-fonts', esc_attr(get_theme_mod('zolog_google_font_url')), false);
    } else {
        wp_enqueue_style('custom-google-fonts', 'https://fonts.googleapis.com/css2?family=Lato&display=swap', false);
    }

    if (!empty($google_font_header)) {
        wp_enqueue_style('custom-google-fonts-header', esc_attr(get_theme_mod('zolog_google_font_header_url')), false);
    } else {
        wp_enqueue_style('custom-google-fonts-header', 'https://fonts.googleapis.com/css2?family=Courgette&display=swap', false);
    }
}

add_action('wp_enqueue_scripts', 'hs_zolog_custom_add_google_fonts');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if (!function_exists('hs_zolog_init_widget_area')) {
    function hs_zolog_init_widget_area()
    {
        register_sidebar(
            array(
                'name' => __('Home: Before Content', 'zolog'),
                'id' => 'hs_zolog_before_content',
                'description' => __('Add your widgets here.', 'zolog'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title">',
                'after_title' => '<span></span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Home: After Content', 'zolog'),
                'id' => 'hs_zolog_after_content',
                'description' => __('Add your widgets here.', 'zolog'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title">',
                'after_title' => '<span></span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Before Footer', 'zolog'),
                'id' => 'hs_zolog_before_footer',
                'description' => __('Add your widgets here.', 'zolog'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title">',
                'after_title' => '<span></span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Left Sidebar', 'zolog'),
                'id' => 'left_sidebar',
                'description' => __('Add your widgets here.', 'zolog'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title">',
                'after_title' => '<span></span></h2>',
            )
        );

        register_sidebar(
            array(
                'name' => __('Right Sidebar', 'zolog'),
                'id' => 'right_sidebar',
                'description' => __('Add your widgets here.', 'zolog'),
                'before_widget' => '<section id="%1$s" class="widget %2$s">',
                'after_widget' => '</section>',
                'before_title' => '<h2 class="widget-title">',
                'after_title' => '<span></span></h2>',
            )
        );

        for ($counter = 1; $counter <= get_option('zolog_footer_columns', '3'); $counter++) :
            $name = 'Footer Column %s';
            $name = sprintf($name, $counter);
            register_sidebar(
                array(
                    'name' => $name,
                    'id' => 'footer' . $counter,
                    'description' => esc_html__('Add your widgets here.', 'zolog'),
                    'before_widget' => '<section id="%1$s" class="widget %2$s">',
                    'after_widget' => '</section>',
                    'before_title' => '<h4 class="widget-title">',
                    'after_title' => '<span></span></h4>',
                )
            );
        endfor;
    }

    add_action('widgets_init', 'hs_zolog_init_widget_area');
}

if (!function_exists('hs_zolog_alter_excerpt')) :
    /**
     * Filter to change excerpt length size
     *
     * @since 1.0.0
     */
    function hs_zolog_alter_excerpt($length)
    {
        if (is_admin()) {
            return $length;
        }

        $content_lentgth = esc_attr(get_theme_mod('zolog_blog_content_length', '50'));
        if (is_archive()) {
            $content_lentgth = esc_attr(get_theme_mod('zolog_archive_content_length', '50'));
        } elseif (is_search()) {
            $content_lentgth = esc_attr(get_theme_mod('zolog_search_content_length', '50'));
        }
        return $content_lentgth;
    }
endif;
add_filter('excerpt_length', 'hs_zolog_alter_excerpt');

function end_excerpt_more($more)
{
    $content_excerpt_end = esc_attr(get_theme_mod('zolog_blog_content_excerpt_end', __('...', 'zolog')));
    if (is_archive()) {
        $content_excerpt_end = esc_attr(get_theme_mod('zolog_archive_content_excerpt_end', __('...', 'zolog')));
    } elseif (is_search()) {
        $content_excerpt_end = esc_attr(get_theme_mod('zolog_search_content_excerpt_end', __('...', 'zolog')));
    }
    return esc_html($content_excerpt_end);
}
add_filter('excerpt_more', 'end_excerpt_more');

/*
 * Custom Comment Form
 */
function hs_zolog_custom_comment_list($comment, $args, $depth)
{ ?>
    <div <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
        <div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
            <?php
            if (0 != $args['avatar_size']) :
                $avatar = get_avatar($comment, $args['avatar_size']);
                if ($avatar) {
            ?>
                    <div class="avatar">
                        <?php echo get_avatar($comment, $args['avatar_size']); ?>
                    </div>
            <?php }
            endif; ?>
            <div class="comment-author">
                <div class="comment-metadata">
                    <div class="name">
                        <?php echo wp_kses(get_comment_author_link(), array('a' => array('href' => array()))); ?>
                    </div>
                    <div class="comment-reply">
                        <?php comment_reply_link(array_merge($args, array('add_below' => 'div-comment', 'class' => '', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                    </div>
                </div>
                <div class="comment-date">
                    <a href="<?php echo esc_url(get_comment_link($comment->comment_ID)); ?>">
                        <?php
                        $time_string = '<span class="date"><time class="entry-date published updated" datetime="%1$s">%2$s</time></span>';
                        $time_string = sprintf(
                            $time_string,
                            esc_attr(get_comment_date(DATE_W3C)),
                            esc_html(get_comment_date("j M, Y"))
                        );
                        echo wp_kses_post($time_string); ?>

                    </a>
                    <?php edit_comment_link(esc_html__('(Edit)', 'zolog'), '<span class="edit-link">', '</span>'); ?>
                </div>
                <div class="comment-content entry-content">
                    <?php comment_text(); ?>
                </div>
            </div>

        </div>
        <div class="comment-footer">
            <?php if ('0' == $comment->comment_approved) : ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'zolog'); ?></p>
            <?php endif; ?>
        </div>
    </div>
<?php
}

if (!function_exists('hs_zolog_move_comment_field_to_bottom')) {
    function hs_zolog_move_comment_field_to_bottom($fields)
    {
        $comment_field = $fields['comment'];
        unset($fields['comment']);
        $fields['comment'] = $comment_field;
        return $fields;
    }

    add_filter('comment_form_fields', 'hs_zolog_move_comment_field_to_bottom');
}

remove_action('set_comment_cookies', 'wp_set_comment_cookies');

if (!function_exists('hs_zolog_hex_to_rgb')) {
    function hs_zolog_hex_to_rgb($hex)
    {
        list($r, $g, $b) = sscanf($hex, "#%02x%02x%02x");
        return array($r, $g, $b);
    }
}

if (!function_exists('hs_zolog_check_post_title')) {
    function hs_zolog_check_post_title($post_title)
    {
        return !empty($post_title) ? $post_title : __('Untitled', 'zolog');
    }
}

/*Remove extra attributes from link and script tag*/
add_action('wp_loaded', 'hs_zolog_output_buffer_start');
function hs_zolog_output_buffer_start()
{
    ob_start("hs_zolog_output_callback");
}

function hs_zolog_output_callback($buffer)
{
    return preg_replace("%[ ]type=[\'\"]text\/(javascript|css)[\'\"]%", '', $buffer);
}

//delete role=navigation
add_filter('navigation_markup_template', 'hs_zolog_navigation_template');
function hs_zolog_navigation_template($template)
{
    $template = '
    <nav class="navigation %1$s">
        <h2 class="screen-reader-text">%2$s</h2>
        <div class="nav-links">%3$s</div>
    </nav>';

    return $template;
}

function zolog_register_meta_boxes()
{
    add_meta_box('zolog_post_options', __('Zolog Options', 'zolog'), 'zolog_options_callback', 'post');
    add_meta_box('zolog_post_options', __('Zolog Options', 'zolog'), 'zolog_options_callback', 'page');
}
add_action('add_meta_boxes', 'zolog_register_meta_boxes');

/**
 * Meta box display callback.
 *
 * @param WP_Post $post Current post object.
 */
function zolog_options_callback($post)
{
?>
<p><?php esc_html_e('Below options can be over writting by "Post Customize" section.', 'zolog'); ?></p>
    <h3><?php esc_html_e('All these options available in Pro version.', 'zolog'); ?></h3>
<?php
}

/******** TGMP */
if (!function_exists('zolog_register_required_plugins')) {
    add_action('tgmpa_register', 'zolog_register_required_plugins');

    function zolog_register_required_plugins()
    {
        $plugins = array(
            array(
                'name'        => __('Regenerate Thumbnails', 'zolog'),
                'slug'        => 'regenerate-thumbnails',
                'required'  => false,
            ),
            array(
                'name'        => __('Simple Local Avatars', 'zolog'),
                'slug'        => 'simple-local-avatars',
                'required'  => false,
            ),
        );

        $config = array(
            'id'           => 'zolog',                 // Unique ID for hashing notices for multiple instances of TGMPA.
            'default_path' => '',                      // Default absolute path to bundled plugins.
            'menu'         => 'tgmpa-install-plugins', // Menu slug.
            'has_notices'  => true,                    // Show admin notices or not.
            'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
            'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
            'is_automatic' => false,                   // Automatically activate plugins after installation or not.
            'message'      => '',                      // Message to output right before the plugins table.
        );

        tgmpa($plugins, $config);
    }
}