<?php
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Zolog_Customize_Upsell {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		get_template_part('/inc/customize/class/Get_Zolog_Pro');

		// Register custom section types.
		$manager->register_section_type( 'Get_Zolog_Pro' );

		// Register sections.
		$manager->add_section(
			new Get_Zolog_Pro(
				$manager,
				'zolog_upsell',
				array(
					'title'    => esc_html__( 'Upgrade to Pro', 'zolog' ),
					'pro_text' => esc_html__( 'Get Zolog Pro',  'zolog' ),
					'pro_url'  => 'https://honarsystems.com/product/zolog-pro/',
					'priority' => -999,
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'zolog-pro-customize-controls', trailingslashit( get_template_directory_uri() ) . 'inc/customize/assets/pro-script.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'zolog-pro-customize-controls', trailingslashit( get_template_directory_uri() ) . 'inc/customize/assets/pro-style.css' );
	}
}

// Doing this customizer thang!
Zolog_Customize_Upsell::get_instance();
