<?php
if (!function_exists('hs_zolog_meta_customizer_register')) {
    function hs_zolog_meta_customizer_register($wp_customize)
    {
        $wp_customize->add_section(
            'zolog_meta',
            array(
                'title' => __('Meta Settings', 'zolog'),
                'capability' => 'edit_theme_options',
                'panel' => 'zolog_settings_pannel'
            )
        );

        /* Google Tag Manager */
        $wp_customize->add_setting('zolog_meta_gtm_code', array(
            // 'default' => '',
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'esc_attr'
        ));

        $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'zolog_meta_gtm_code', array(
            'type' => 'text',
            'label' => __('Google Tag Manager ID (GTM-XXXX)', 'zolog'),
            'description' => __('Add Google Tag Manager code to display inside head tag.', 'zolog'),
            'section' => 'zolog_meta',
            'settings' => 'zolog_meta_gtm_code'
        )));

        /* Google Analytics Code */
        $wp_customize->add_setting('zolog_meta_ga_code', array(
            // 'default' => '',
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'esc_attr'
        ));

        $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'zolog_meta_ga_code', array(
            'type' => 'text',
            'label' => __('Google Analytics ID (UA-XXXXX-Y)', 'zolog'),
            'description' => __('Add Google Analytics code to display inside head tag.', 'zolog'),
            'section' => 'zolog_meta',
            'settings' => 'zolog_meta_ga_code'
        )));
    }
    add_action('customize_register', 'hs_zolog_meta_customizer_register');
}

if (!function_exists('hs_zolog_meta_customizer_css')) {
    function hs_zolog_meta_customizer_css()
    {
        $gtm_code = esc_attr(get_theme_mod('zolog_meta_gtm_code', ''));
        if (!empty($gtm_code)) :
            wp_add_inline_script('zolog-main-script', "
            (function(w, d, s, l, i) {
                w[l] = w[l] || [];
                w[l].push({
                    'gtm.start': new Date().getTime(),
                    event: 'gtm.js'
                });
                var f = d.getElementsByTagName(s)[0],
                    j = d.createElement(s),
                    dl = l != 'dataLayer' ? '&l=' + l : '';
                j.async = true;
                j.src =
                    'https://www.googletagmanager.com/gtm.js?id=' + i + dl;
                f.parentNode.insertBefore(j, f);
            })(window, document, 'script', 'dataLayer', '" . esc_js($gtm_code) . "');
            ", 'before');
        endif;

        $ga_code = esc_attr(get_theme_mod('zolog_meta_ga_code', ''));
        if (!empty($ga_code)) :
            wp_add_inline_script('zolog-main-script', "
            window.ga = window.ga || function() {
                (ga.q = ga.q || []).push(arguments)
            };
            ga.l = +new Date;
            ga('create', '" . esc_js($ga_code) . "', 'auto');
            ga('send', 'pageview');
            ", 'before');
        endif;
    }

    add_action('wp_head', 'hs_zolog_meta_customizer_css');
}
