<?php
if (!function_exists('hs_zolog_slider_customizer_register')) {
    function hs_zolog_slider_customizer_register($wp_customize)
    {
        get_template_part('/inc/customize/class/Text_Radio_Button');
        get_template_part('/inc/customize/class/Input_Number_Option');

        $wp_customize->add_section(
            'zolog_slider',
            array(
                'title' => __('Slider', 'zolog'),
                'capability' => 'edit_theme_options',
                'panel' => 'zolog_settings_pannel'
            )
        );

        $wp_customize->add_setting(
            'zolog_slider_display',
            array(
                'default'     => 'yes',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_display',
            array(
                'label'      => __('Slider', 'zolog'),
                'description' => __('Hide or display slider of the website. This slider only will be displayed in home page. To use slider in other pages, use Zolog Slider widget.', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_display',
                'choices'    => array(
                    'yes' => __('Show', 'zolog'),
                    'no' => __('Hide', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting(
            'zolog_slider_width',
            array(
                'default'     => 'wide',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_width',
            array(
                'label'      => __('Slider Width', 'zolog'),
                'description' => __('Wide or boxed the slider.', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_width',
                'choices'    => array(
                    'wide' => __('Wide', 'zolog'),
                    'boxed' => __('Boxed', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting(
            'zolog_slider_mode',
            array(
                'default'     => 'latest_posts',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_mode',
            array(
                'label'      => __('Based On', 'zolog'),
                'description' => __('In this option you can choose to display content of the slider based on latest posts, category or tag.', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_mode',
                'choices'    => array(
                    'latest_posts' => __('Latest Posts', 'zolog'),
                    'category' => __('Category', 'zolog'),
                    'tag' => __('Tag', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting('zolog_slider_category', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'zolog_sanitize_select',
            'default' => esc_attr(get_option('zolog_slider_category', '-1')),
        ));

        $categories = get_categories(array(
            'orderby' => 'name',
            'order'   => 'ASC'
        ));

        $category_options = array();

        $category_options['-1'] = __('Select', 'zolog');

        foreach ($categories as $category) {
            $category_options[$category->term_id] = $category->name;
        }

        $wp_customize->add_control('zolog_slider_category', array(
            'type' => 'select',
            'section' => 'zolog_slider',
            'label' => __('Category', 'zolog'),
            'description' => __('Choose category to display. Leave it blank to display latest posts.', 'zolog'),
            'description' => __('Choose item to display in slider.', 'zolog'),
            'settings' => 'zolog_slider_category',
            'choices' => $category_options,
        ));

        $wp_customize->add_setting('zolog_slider_tag', array(
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'zolog_sanitize_select',
            'default' => esc_attr(get_option('zolog_slider_tag', '-1')),
        ));

        $tags = get_tags(array(
            'orderby' => 'name',
            'order'   => 'ASC'
        ));

        $tag_options = array();

        $tag_options['-1'] = __('Select', 'zolog');

        foreach ($tags as $tag) {
            $tag_options[$tag->term_id] = $tag->name;
        }

        $wp_customize->add_control('zolog_slider_tag', array(
            'type' => 'select',
            'section' => 'zolog_slider',
            'label' => __('Tags', 'zolog'),
            'description' => __('Choose tag to display. Leave it blank to display latest posts.', 'zolog'),
            'description' => __('Choose item to display in slider.', 'zolog'),
            'settings' => 'zolog_slider_tag',
            'choices' => $tag_options,
        ));

        $wp_customize->add_setting('zolog_slider_sidplay_count', array(
            'default' => '3',
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'esc_attr'
        ));

        $wp_customize->add_control(new hs_Zolog_Input_Number_Option($wp_customize, 'zolog_slider_sidplay_count', array(
            'type' => 'input',
            'label' => __('Posts Display Count', 'zolog'),
            'description' => __('Choose how many posts will be displayed in slider.', 'zolog'),
            'section' => 'zolog_slider',
            'settings' => 'zolog_slider_sidplay_count',
            'choices' => array(
                'columns' => '3'
            )
        )));

        $wp_customize->add_setting(
            'zolog_slider_display_meta_box',
            array(
                'default'     => 'yes',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_display_meta_box',
            array(
                'label'      => __('Meta Box (Available in Pro)', 'zolog'),
                'description' => __('Hide or display the meta box (Title, Category, Author Name, ...).', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_display_meta_box',
                'disabled'  => true,
                'choices'    => array(
                    'yes' => __('Show', 'zolog'),
                    'no' => __('Hide', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting(
            'zolog_slider_display_meta_category',
            array(
                'default'     => 'yes',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_display_meta_category',
            array(
                'label'      => __('Category (Available in Pro)', 'zolog'),
                'description' => __('Hide or display category of the post in slider.', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_display_meta_category',
                'disabled'  => true,
                'choices'    => array(
                    'yes' => __('Show', 'zolog'),
                    'no' => __('Hide', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting(
            'zolog_slider_display_meta_meta',
            array(
                'default'     => 'yes',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_display_meta_meta',
            array(
                'label'      => __('Meta (Available in Pro)', 'zolog'),
                'description' => __('Hide or display meta (author name and date) of the post in slider.', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_display_meta_meta',
                'disabled'  => true,
                'choices'    => array(
                    'yes' => __('Show', 'zolog'),
                    'no' => __('Hide', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting(
            'zolog_slider_display_meta_read_more',
            array(
                'default'     => 'yes',
                'sanitize_callback' => 'esc_attr',
                'transport' => 'refresh',
            )
        );

        $wp_customize->add_control(new hs_zolog_Text_Radio_Button_Custom_Control(
            $wp_customize,
            'zolog_slider_display_meta_read_more',
            array(
                'label'      => __('Read More (Available in Pro)', 'zolog'),
                'description' => __('Hide or display read more button of the post in slider.', 'zolog'),
                'section'    => 'zolog_slider',
                'settings'   => 'zolog_slider_display_meta_read_more',
                'disabled'  => true,
                'choices'    => array(
                    'yes' => __('Show', 'zolog'),
                    'no' => __('Hide', 'zolog')
                ),
            )
        ));

        $wp_customize->add_setting('zolog_slider_meta_read_more_text', array(
            'default' => 'Read More',
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'esc_attr'
        ));

        $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'zolog_slider_meta_read_more_text', array(
            'type' => 'text',
            'label' => __('Read More Text', 'zolog'),
            'description' => __('Change read more button text.', 'zolog'),
            'section' => 'zolog_slider',
            'settings' => 'zolog_slider_meta_read_more_text'
        )));

        $wp_customize->add_setting('zolog_slider_autoplay_speed', array(
            'default' => '4000',
            'capability' => 'edit_theme_options',
            'sanitize_callback' => 'esc_attr'
        ));

        $wp_customize->add_control(new hs_Zolog_Input_Number_Option($wp_customize, 'zolog_slider_autoplay_speed', array(
            'type' => 'input',
            'label' => __('Autoplay Speed (Milisecond) (Available in Pro)', 'zolog'),
            'description' => __('Change the slider autoplay speed to increase user experience.', 'zolog'),
            'section' => 'zolog_slider',
            'settings' => 'zolog_slider_autoplay_speed',
            'disabled'  => true,
            'choices' => array(
                'columns' => '4000'
            )
        )));
    }
    add_action('customize_register', 'hs_zolog_slider_customizer_register');
}
