<?php
function hs_zolog_body_classes( $classes ) {

    // Helps detect if JS is enabled or not.
    $classes[] = 'no-js';

    // Adds `singular` to singular pages, and `hfeed` to all other pages.
    $classes[] = is_singular() ? 'singular' : 'hfeed';

    return $classes;
}
add_filter( 'body_class', 'hs_zolog_body_classes' );

function hs_zolog_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'hs_zolog_pingback_header' );

/**
 * Remove the `no-js` class from body if JS is supported.
 */
function hs_zolog_supports_js() {
    echo '<script>document.body.classList.remove("no-js");</script>';
}
add_action( 'wp_footer', 'hs_zolog_supports_js' );

/**
 * Changes comment form default fields.
 */
function hs_zolog_comment_form_defaults( $defaults ) {

    // Adjust height of comment form.
    $defaults['comment_field'] = preg_replace( '/rows="\d+"/', 'rows="5"', $defaults['comment_field'] );

    return $defaults;
}
add_filter( 'comment_form_defaults', 'hs_zolog_comment_form_defaults' );

/**
 * Determines if post thumbnail can be displayed.
 *
 * @since Zolog 1.0
 *
 * @return bool
 */
function hs_zolog_can_show_post_thumbnail() {
    return apply_filters(
        'hs_zolog_can_show_post_thumbnail',
        ! post_password_required() && ! is_attachment() && has_post_thumbnail()
    );
}

if ( ! function_exists( 'hs_zolog_post_title' ) ) {
    /**
     * Add a title to posts and pages that are missing titles.
     */
    function hs_zolog_post_title( $title ) {
        return '' === $title ? esc_html_x( 'Untitled', 'Added to posts and pages that are missing titles', 'zolog' ) : $title;
    }
}
add_filter( 'the_title', 'hs_zolog_post_title' );

// /**
//  * Print the first instance of a block in the content, and then break away.
//  */
function hs_zolog_print_first_instance_of_block( $block_name, $content = null, $instances = 1 ) {
    $instances_count = 0;
    $blocks_content  = '';

    if ( ! $content ) {
        $content = get_the_content();
    }

    // Parse blocks in the content.
    $blocks = parse_blocks( $content );

    // Loop blocks.
    foreach ( $blocks as $block ) {

        // Sanity check.
        if ( ! isset( $block['blockName'] ) ) {
            continue;
        }

        // Check if this the block matches the $block_name.
        $is_matching_block = false;

        // If the block ends with *, try to match the first portion.
        if ( '*' === $block_name[-1] ) {
            $is_matching_block = 0 === strpos( $block['blockName'], rtrim( $block_name, '*' ) );
        } else {
            $is_matching_block = $block_name === $block['blockName'];
        }

        if ( $is_matching_block ) {
            // Increment count.
            $instances_count++;

            // Add the block HTML.
            $blocks_content .= render_block( $block );

            // Break the loop if the $instances count was reached.
            if ( $instances_count >= $instances ) {
                break;
            }
        }
    }

    if ( $blocks_content ) {
        /** This filter is documented in wp-includes/post-template.php */
        echo apply_filters( 'the_content', $blocks_content ); // phpcs:ignore WordPress.Security.EscapeOutput
        return true;
    }

    return false;
}

// /**
//  * Retrieve protected post password form content.
//  *
//  * @since Zolog 1.0
//  *
//  * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
//  * @return string HTML content for password form for password protected post.
//  */
function hs_zolog_password_form( $post = 0 ) {
    $post   = get_post( $post );
    $label  = 'pwbox-' . ( empty( $post->ID ) ? wp_rand() : $post->ID );
    $output = '<p class="post-password-message">' . esc_html__( 'This content is password protected. Please enter a password to view.', 'zolog' ) . '</p>
	<form action="' . esc_url( home_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="post-password-form" method="post">
	<label class="post-password-form__label" for="' . esc_attr( $label ) . '">' . esc_html_x( 'Password', 'Post password form', 'zolog' ) . '</label><input class="post-password-form__input" name="post_password" id="' . esc_attr( $label ) . '" type="password" size="20" /><input type="submit" class="post-password-form__submit" name="' . esc_attr_x( 'Submit', 'Post password form', 'zolog' ) . '" value="' . esc_attr_x( 'Enter', 'Post password form', 'zolog' ) . '" /></form>
	';
    return $output;
}
add_filter( 'the_password_form', 'hs_zolog_password_form' );

if ( ! function_exists( 'zolog_get_option' ) ) :
    function zolog_get_option($id) {
        if (!$id) {
            return;
        }
        if (get_theme_mod($id) !== null) {
            return get_theme_mod($id);
        }
    }
    endif;