<?php
if (!function_exists('hs_zolog_post_thumbnail')) {
    function hs_zolog_post_thumbnail()
    {
        if (has_post_thumbnail()) :
            $thumbnail_size = 'zolog-blog-thumbnail';
            if (is_archive()) {
                $thumbnail_size = 'zolog-archive-thumbnail';
            } elseif (is_search()) {
                $thumbnail_size = 'zolog-search-thumbnail';
            } elseif (is_singular()) {
                if (is_page()) {
                    $thumbnail_size =  'full';
                } else {
                    $thumbnail_size = 'full';
                }
            }
?>
            <?php if (is_singular()) : ?>
                <div class="post-thumbnail">
                    <?php the_post_thumbnail($thumbnail_size); ?>
                </div>
            <?php else : ?>
                <a href="<?php echo esc_url(get_permalink()); ?>">
                    <div class="post-thumbnail">
                        <?php the_post_thumbnail($thumbnail_size); ?>
                        <?php
                        switch (get_post_format()) {
                            case 'audio':
                                echo '<span class="dashicons dashicons-format-audio"></span>';
                                break;
                            case 'image':
                                echo '<span class="dashicons dashicons-format-image"></span>';
                                break;
                            case 'video':
                                echo '<span class="dashicons dashicons-controls-play"></span>';
                                break;
                            case 'quote':
                                echo '<span class="dashicons dashicons-format-quote"></span>';
                                break;
                            case 'chat':
                                echo '<span class="dashicons dashicons-format-chat"></span>';
                                break;
                            case 'gallery':
                                echo '<span class="dashicons dashicons-format-gallery"></span>';
                                break;
                            case 'link':
                                echo '<span class="dashicons dashicons-admin-links"></span>';
                                break;
                        }
                        ?>
                    </div>
                </a>
            <?php endif; ?>
        <?php
        endif;
    }
}

if (!function_exists('hs_zolog_entry_category')) {
    function hs_zolog_entry_category()
    {

        $categories_list = get_the_category_list();
        if ($categories_list) : ?>
            <div class="entry-categories">
                <?php printf('<span class="screen-reader-text">%1$s </span>%2$s', esc_html__('Used before category names.', 'zolog'), wp_kses($categories_list, array('a' => array('href' => array(), 'rel' => array())))); ?>
            </div>
        <?php
        endif;
    }
}

if (!function_exists('hs_zolog_entry_title')) {
    function hs_zolog_entry_title()
    {
        ?>
        <?php if (is_singular()) : ?>
            <?php if (is_sticky()) : ?>
                <?php
                the_title(sprintf('<h1 class="entry-title"><span class="dashicons dashicons-sticky"></span> ', esc_url(get_permalink())), '</h1>');
                ?>
            <?php else : ?>
                <?php
                the_title(sprintf('<h1 class="entry-title">', esc_url(get_permalink())), '</h1>');
                ?>
            <?php endif; ?>
        <?php else : ?>
            <?php if (is_sticky()) : ?>
                <?php
                the_title(sprintf('<h2 class="entry-title"><span class="dashicons dashicons-sticky"></span><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>');
                ?>
            <?php else : ?>
                <?php the_title(sprintf('<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>'); ?>
            <?php endif; ?>
        <?php endif; ?>
    <?php
    }
}

if (!function_exists('hs_zolog_entry_published_date')) {
    function hs_zolog_entry_published_date()
    {
        $time_string = '<span class="date"><time class="entry-date published updated" datetime="%1$s">%2$s</time></span>';

    ?>
        <span class="entry-date">
            <?php if (is_singular()) :
                $time_string = sprintf(
                    $time_string,
                    esc_attr(get_the_date(DATE_W3C)),
                    esc_html(get_the_date("j M, Y"))
                );
                echo wp_kses_post($time_string); ?>
            <?php else : ?>
                <?php
                $time_string = sprintf(
                    $time_string,
                    esc_attr(get_the_date(DATE_W3C)),
                    esc_html(get_the_date("j F, Y"))
                );
                echo wp_kses_post($time_string); ?>
            <?php endif; ?>
        </span>
    <?php
    }
}

if (!function_exists('hs_zolog_entry_author')) {
    function hs_zolog_entry_author()
    {
    ?>
        <span class="entry-author">
            <span class="byline"><?php esc_html_e('by: ', 'zolog') ?><span><?php the_author(); ?></span>
            </span>
        </span>
    <?php
    }
}

if (!function_exists('hs_zolog_entry_content')) {
    function hs_zolog_entry_content()
    {
    ?>
        <div class="entry-content">
            <?php get_template_part('template-parts/excerpt/excerpt', get_post_format()); ?>
        </div>
    <?php
    }
}

if (!function_exists('hs_zolog_entry_share_buttons')) {
    function hs_zolog_entry_share_buttons()
    {
    ?>
        <?php if (esc_attr(get_theme_mod('zolog_fontawesome_display', 'yes')) == 'yes') : ?>
            <div class="entry-share">
                <span class="share-icon">
                    <i class="fa fa-share-alt <?php echo is_rtl() ? 'fa-flip-horizontal' : '' ?>"></i>
                </span>
                <?php if (esc_attr(get_theme_mod('zolog_facebook_display', 'yes')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>" class="share_facebook" onclick="if (navigator.share) {
  navigator.share({
		title: document.title,
	  text: '<?php the_title(); ?>',
	  url: '<?php the_permalink(); ?>',
  })
} else {window.open('https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>&display=popup', 'facebook-share-dialog', 'width=626,height=436');
	                                return false;} "><i class="fa fa-facebook"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_twitter_display', 'yes')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" href="https://twitter.com/share?url=<?php the_permalink(); ?>" target="_blank" class="share_twitter"><i class="fa fa-twitter"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_gplus_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" href="https://plus.google.com/share?url=<?php the_permalink(); ?>" onclick="javascript:window.open(this.href,
	                                        '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');
	                                return false;" class="share_googleplus"><i class="fa fa-google-plus"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_linkedin_display', 'yes')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php the_permalink(); ?>" target="_blank" class="share_linkedin"><i class="fa fa-linkedin"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_pinterest_display', 'yes')) == 'yes') : ?>
                    <?php
                    $image_url = '';
                    if (has_post_thumbnail()) {
                        $image_url = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                        $image_url = $image_url[0];
                    }

                    $pinterest_title = str_replace(' ', '%20', get_the_title());
                    $pinterest_media = '';
                    $pinterest_media_sep = '';
                    if ($image_url != '') {
                        $pinterest_media_sep = '&amp;media=';
                        $pinterest_media =  $image_url;
                    }
                    $pin_url = 'https://www.pinterest.com/pin/create/button/?url=' . get_the_permalink() . esc_attr($pinterest_media_sep) . esc_url($pinterest_media) . '&amp;description=' . esc_attr($pinterest_title);
                    ?>
                    <a rel="nofollow noreferrer" href="<?php echo esc_url($pin_url); ?>" class="share_pinterest" target="_blank" data-pin-custom="true"><i class="fa fa-pinterest"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_reddit_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" href="https://reddit.com/submit?url=<?php the_permalink(); ?>" class="share_reddit" target="_blank"><i class="fa fa-reddit"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_tumblr_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" href="https://www.tumblr.com/share/link?url=<?php the_permalink(); ?>" class="share_tumblr" target="_blank"><i class="fa fa-tumblr"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_vk_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" href="https://vk.com/share.php?url=<?php the_permalink(); ?>" class="share_vk" target="_blank"><i class="fa fa-vk"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_pocket_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" target="_blank" class="share_pinterest" href="https://getpocket.com/save?url=<?php the_permalink(); ?>&title=<?php echo esc_attr($pinterest_title); ?>" data-event-category="Social" data-event-action="Share:pocket"><i class="fa fa-get-pocket"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_whatsapp_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" class="share_whatsapp" href="whatsapp://send?text=<?php the_permalink(); ?>" data-action="share/whatsapp/share"><i class="fa fa-whatsapp"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_telegram_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" target="_blank" class="share_telegram" href="https://t.me/share/url?url=<?php the_permalink(); ?>"><i class="fa fa-telegram"></i></a>
                <?php endif; ?>

                <?php if (esc_attr(get_theme_mod('zolog_mail_display', 'no')) == 'yes') : ?>
                    <a rel="nofollow noreferrer" target="_blank" class="share_mail" href="mailto:?body=<?php the_permalink(); ?>"><i class="fa fa-envelope"></i></a>
                <?php endif; ?>
            </div>

            <!-- </div> -->
        <?php endif; ?>


        <?php
    }
}

if (!function_exists('hs_zolog_entry_comments_number')) {
    function hs_zolog_entry_comments_number()
    {
        if (comments_open()) : ?>
            <span class="entry-comment-count">
                <?php
                $comments_number = get_comments_number(); ?>
                <?php if ('0' === $comments_number) : ?>
                    <?php esc_html_e("No Comment", 'zolog') ?>
                <?php elseif ('1' === $comments_number) : ?>
                    <?php esc_html_e("One Comment", 'zolog') ?>
                <?php else : ?>
                    <?php echo esc_html($comments_number); ?><?php esc_html_e(" Comments", 'zolog') ?>
                <?php endif; ?>
            </span>
        <?php
        endif;
    }
}

if (!function_exists('hs_zolog_entries_pagination')) {
    function hs_zolog_entries_pagination()
    {
        if (is_rtl()) {
            the_posts_pagination(array(
                'prev_text' => __('<span class="dashicons dashicons-arrow-right-alt2"></span>', 'zolog'),
                'next_text' => __('<span class="dashicons dashicons-arrow-left-alt2"></span>', 'zolog'),
            ));
        } else {
            the_posts_pagination(array(
                'prev_text' => __('<span class="dashicons dashicons-arrow-left-alt2"></span>', 'zolog'),
                'next_text' => __('<span class="dashicons dashicons-arrow-right-alt2"></span>', 'zolog'),
            ));
        }
    }
}

if (!function_exists('hs_zolog_post_navigation')) {
    function hs_zolog_post_navigation()
    {
        $prev_post = get_adjacent_post(false, '', true);
        $next_post = get_adjacent_post(false, '', false);
        if (!empty($prev_post) || !empty($next_post)) :
            $prev_title = '';
            $next_title = '';
            if (is_single()) {
                $prev_title = !empty(esc_attr(get_theme_mod('zolog_single_navigation_prev_title', 'Previous Article'))) ? '<div>' . esc_attr(get_theme_mod('zolog_single_navigation_prev_title', 'Previous Article')) . '</div>' : '';
                $next_title = !empty(esc_attr(get_theme_mod('zolog_single_navigation_next_title', 'Next Article'))) ? '<div>' . esc_attr(get_theme_mod('zolog_single_navigation_next_title', 'Next Article')) . '</div>' : '';
            } else {
                $prev_title = !empty(esc_attr(get_theme_mod('zolog_page_navigation_prev_title', 'Previous Article'))) ? '<div>' . esc_attr(get_theme_mod('zolog_page_navigation_prev_title', 'Previous Article')) . '</div>' : '';
                $next_title = !empty(esc_attr(get_theme_mod('zolog_page_navigation_next_title', 'Next Article'))) ? '<div>' . esc_attr(get_theme_mod('zolog_page_navigation_next_title', 'Next Article')) . '</div>' : '';
            }
        ?>
            <div class="entry-navigation">
                <div class="pre-post">
                    <?php

                    if (!empty($prev_post)) { ?>
                        <?php echo wp_kses_post($prev_title); ?>
                        <a href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>" title="<?php echo esc_attr(hs_zolog_check_post_title($prev_post->post_title)); ?>">
                            <div><?php echo esc_html(hs_zolog_check_post_title($prev_post->post_title)); ?></div>
                        </a>
                    <?php
                    }
                    ?>
                </div>
                <div class="next-post">
                    <?php

                    if (!empty($next_post)) { ?>
                        <?php echo wp_kses_post($next_title); ?>
                        <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>" title="<?php echo esc_attr(hs_zolog_check_post_title($next_post->post_title)); ?>">
                            <div><?php echo esc_html(hs_zolog_check_post_title($next_post->post_title)); ?></div>
                        </a>
                    <?php
                    }
                    ?>
                </div>
            </div>
        <?php
        endif;
    }
}

if (!function_exists('hs_zolog_post_tags')) {
    function hs_zolog_post_tags()
    {
        $tags_list = get_the_tag_list('', _x(', ', 'Used between list items, there is a space after the comma.', 'zolog'));
        if ($tags_list && !is_wp_error($tags_list)) :
            $tag_title = !empty(esc_attr(get_theme_mod('zolog_single_tag_title', 'Tags:'))) ? '<span class="tag-title">' . esc_attr(get_theme_mod('zolog_single_tag_title', 'Tags:')) . '</span>' : '';
        ?>
            <div class="entry-tags">
                <?php
                printf(
                    '%1$s %2$s',
                    wp_kses($tag_title, array('span' => array('class' => array()))),
                    wp_kses($tags_list, array('a' => array('href' => array(), 'rel' => array())))

                );
                ?>
            </div>
        <?php
        endif;
    }
}

if (!function_exists('hs_zolog_post_avatar')) {
    function hs_zolog_post_avatar()
    {
        if ('post' === get_post_type()) : ?>
            <div class="entry-avatar">
                <?php
                $author_avatar_size = apply_filters('zolog_author_avatar_size', 100); ?>
                <span class="screen-reader-text"><?php esc_html_e('Used before post author name.', 'zolog'); ?></span>
                <div class="author-avatar"><?php echo get_avatar(get_the_author_meta('user_email'), $author_avatar_size); ?></div>
                <div class="author-meta">
                    <div class="author-name"><a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>"><?php echo get_the_author(); ?></a>
                    </div>
                    <div class="author-description"><?php echo esc_html(get_the_author_meta('description')); ?></div>
                </div>
            </div>
        <?php
        endif;
    }
}

if (!function_exists('hs_zolog_related_posts')) {
    function hs_zolog_related_posts()
    {
        if (is_single()) : ?>
            <?php
            $categories = get_the_category();
            if (count($categories) > 0) :
            ?>

                <?php
                $terms = get_the_terms(get_the_ID(), 'category');

                if (empty($terms)) $terms = array();

                $term_list = wp_list_pluck($terms, 'slug');

                $related_args = array(
                    'post_type' => 'post',
                    'posts_per_page' => 3,
                    'post_status' => 'publish',
                    'post__not_in' => array(get_the_ID()),
                    //                        'orderby' => 'rand',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'category',
                            'field' => 'slug',
                            'terms' => $term_list
                        )
                    )
                );

                $the_query = new WP_Query($related_args);
                global $cl_from_element;
                $cl_from_element['is_related'] = true;
                // Display posts
                if ($the_query->have_posts()) :
                ?>
                    <div class="related-posts">
                        <h2 class="widget-title">
                            <?php esc_html_e('Related Posts', 'zolog') ?>
                        </h2>
                        <div class="posts">
                            <?php $counter = 1;
                            while ($the_query->have_posts() && $counter < 4) :
                                $the_query->the_post(); ?>
                                <div class="related-post">

                                    <a href="<?php echo esc_url(get_permalink()); ?>">
                                        <?php if (has_post_thumbnail()) : ?>
                                            <div class="related-post-thumbnail">
                                                <?php the_post_thumbnail('zolog-blog-thumbnail'); ?>
                                            </div>
                                        <?php endif; ?>

                                        <?php the_title(sprintf('<h2 class="related-post-title">', '</h2>')); ?>
                                    </a>
                                </div>
                            <?php
                                $counter++;
                            endwhile;
                            ?>
                        </div>
                    </div>
                <?php endif;

                wp_reset_query();
                $cl_from_element['is_related'] = false;
                ?>

            <?php endif;
        endif;
    }
}

if (!function_exists('hs_zolog_post_comment')) {
    function hs_zolog_post_comment()
    {
        if (get_theme_mod('zolog_comment_display', 'yes') == 'yes') :
            if (comments_open() || get_comments_number()) : ?>
                <div class="entry-comment">
                    <?php comments_template(); ?>
                </div>
            <?php elseif (!comments_open()) : ?>
<?php
                $close_comment_msg = get_theme_mod('zolog_comment_close_message', __('Comments are closed for this section.', 'zolog'));
                if (!empty($close_comment_msg)) :
                    sprintf('<div class="entry-comment">%1$s</div>', $close_comment_msg);
                endif;
            endif;
        endif;
    }
}
