<?php
class hs_about_me_widget extends WP_Widget
{
    function __construct()
    {
        add_action('wp_enqueue_scripts', array($this, 'hs_scripts'));
        add_action('admin_enqueue_scripts', array($this, 'hs_admin_scripts'));

        parent::__construct(
            // widget ID
            'zolog_about_me_widget',
            // widget name
            __('Zolog: About Me', 'zolog'),
            // widget description
            array('description' => __('About Me widget.', 'zolog'),)
        );
    }

    public function hs_scripts()
    {
        wp_enqueue_style('zolog-widget-about-me', get_template_directory_uri() . '/widgets/about-me/about-me.css', array('zolog-style'), null);
    }

    public function hs_admin_scripts()
    {
        wp_enqueue_script('zolog-about-me-script', get_template_directory_uri() . '/assets/js/admin.js', array('jquery'), '1.0.0', true);
    }

    public function widget($args, $instance)
    {
        extract($args, EXTR_SKIP);
        echo wp_kses_post($args['before_widget']);
        $about_me_theme = !empty($instance['zolog_about_me_theme']) ? $instance['zolog_about_me_theme'] : '1';
        try {
?>
            <div class="zolog-about-me-widget widget <?php echo !empty($instance['zolog_boxed_layout']) ? 'zolog-boxed' : ''; ?>">
                <?php get_template_part('/widgets/about-me/theme/theme', $about_me_theme, $instance); ?>
            </div>
        <?php

        } catch (Exception $ex) {
            echo '';
        }
        echo wp_kses_post($args['after_widget']);
    }

    public function form($instance)
    {
        $defaults = array(
            'zolog_about_me_title' => '',
            'zolog_about_me_profile_image' => '',
            'zolog_about_me_name' => '',
            'zolog_about_me_sub_title' => '',
            'zolog_about_me_description' => '',
            'zolog_boxed_layout' => '',
            'zolog_about_me_theme' => '1',
            'zolog_about_me_email' => '',
            'zolog_about_me_twitter' => '',
            'zolog_about_me_linkedin' => '',
            'zolog_about_me_youtube' => '',
            'zolog_about_me_instagram' => '',
            'zolog_about_me_google_plus' => '',
            'zolog_about_me_facebook' => '',
            'zolog_about_me_pinterest' => '',
            'zolog_about_me_whatsapp' => '',
            'zolog_about_me_reddit' => '',

        );
        extract(wp_parse_args((array)$instance, $defaults));

        $boxed_layout = !empty($instance['zolog_boxed_layout']) ? $instance['zolog_boxed_layout'] : '';
        $zolog_about_me_title = !empty($instance['zolog_about_me_title']) ? $instance['zolog_about_me_title'] : '';
        $image = !empty($instance['zolog_about_me_profile_image']) ? $instance['zolog_about_me_profile_image'] : '';
        $zolog_about_me_name = !empty($instance['zolog_about_me_name']) ? $instance['zolog_about_me_name'] : '';
        $zolog_about_me_sub_title = !empty($instance['zolog_about_me_sub_title']) ? $instance['zolog_about_me_sub_title'] : '';
        $zolog_about_me_description = !empty($instance['zolog_about_me_description']) ? $instance['zolog_about_me_description'] : '';
        $zolog_about_me_theme = !empty($instance['zolog_about_me_theme']) ? $instance['zolog_about_me_theme'] : '1';

        $zolog_about_me_email = !empty($instance['zolog_about_me_email']) ? $instance['zolog_about_me_email'] : '';
        $zolog_about_me_twitter = !empty($instance['zolog_about_me_twitter']) ? $instance['zolog_about_me_twitter'] : '';
        $zolog_about_me_linkedin = !empty($instance['zolog_about_me_linkedin']) ? $instance['zolog_about_me_linkedin'] : '';
        $zolog_about_me_youtube = !empty($instance['zolog_about_me_youtube']) ? $instance['zolog_about_me_youtube'] : '';
        $zolog_about_me_instagram = !empty($instance['zolog_about_me_instagram']) ? $instance['zolog_about_me_instagram'] : '';
        $zolog_about_me_google_plus = !empty($instance['zolog_about_me_google_plus']) ? $instance['zolog_about_me_google_plus'] : '';
        $zolog_about_me_facebook = !empty($instance['zolog_about_me_facebook']) ? $instance['zolog_about_me_facebook'] : '';
        $zolog_about_me_pinterest = !empty($instance['zolog_about_me_pinterest']) ? $instance['zolog_about_me_pinterest'] : '';
        $zolog_about_me_whatsapp = !empty($instance['zolog_about_me_whatsapp']) ? $instance['zolog_about_me_whatsapp'] : '';
        $zolog_about_me_reddit = !empty($instance['zolog_about_me_reddit']) ? $instance['zolog_about_me_reddit'] : '';

        ?>
        <p>
            <input type="checkbox" name="<?php echo esc_attr($this->get_field_name('zolog_boxed_layout')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_boxed_layout')); ?>" class="widefat" <?php echo esc_attr($boxed_layout); ?>>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_boxed_layout')); ?>"><?php esc_html_e('Boxed', 'zolog'); ?></label>
        </p>
        <h3><?php esc_html_e('Title', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_title')); ?>"><?php esc_html_e('Title:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_title')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_title')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_title); ?>">
        </p>
        <h3><?php esc_html_e('Profile Image', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_profile_image')); ?>"><?php esc_html_e('Image:', 'zolog'); ?></label>
            <img class="widefat" src="<?php echo esc_url($image); ?>" />
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_profile_image')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_profile_image')); ?>" type="hidden" value="<?php echo esc_url($image); ?>" />
            <button class="upload_image_button button button-primary"><?php esc_html_e('Upload Image', 'zolog') ?></button>
        </p>
        <h3><?php esc_html_e('Title', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_name')); ?>"><?php esc_html_e('Name:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_name')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_name')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_name); ?>">
        </p>

        <h3><?php esc_html_e('Sub Title', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_sub_title')); ?>"><?php esc_html_e('Sub Title:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_sub_title')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_sub_title')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_sub_title); ?>">
        </p>

        <h3><?php esc_html_e('Description', 'zolog'); ?></h3>
        <p>
            <?php
            $settings = array('media_buttons' => true, 'textarea_rows' => 4, 'textarea_name' => $this->get_field_name('zolog_about_me_description'), 'teeny' => true,);
            wp_editor($zolog_about_me_description, $this->get_field_id('zolog_about_me_description'), $settings); ?>
        </p>

        <h3><?php esc_html_e('Layout', 'zolog'); ?></h3>
        <p>
            <select name="<?php echo esc_attr($this->get_field_name('zolog_about_me_theme')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_theme')); ?>" class="widefat">
                <option value="1" id="theme1" <?php echo esc_html($zolog_about_me_theme == '1' ? 'selected' : ''); ?>><?php esc_html_e('Theme One', 'zolog'); ?></option>
                <option value="2" id="theme2" <?php echo esc_html($zolog_about_me_theme == '2' ? 'selected' : ''); ?>><?php esc_html_e('Theme Two', 'zolog'); ?></option>
            </select>
        </p>

        <h3><?php esc_html_e('Social Media', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_email')); ?>"><?php esc_html_e('Email:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_email')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_email')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_email); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_facebook')); ?>"><?php esc_html_e('Facebook Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_facebook')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_facebook')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_facebook); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_twitter')); ?>"><?php esc_html_e('Twitter Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_twitter')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_twitter')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_twitter); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_linkedin')); ?>"><?php esc_html_e('LinkedIn Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_linkedin')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_linkedin')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_linkedin); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_pinterest')); ?>"><?php esc_html_e('Pinterest Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_pinterest')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_pinterest')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_pinterest); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_instagram')); ?>"><?php esc_html_e('Instagram Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_instagram')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_instagram')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_instagram); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_google_plus')); ?>"><?php esc_html_e('Google Plus Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_google_plus')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_google_plus')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_google_plus); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_whatsapp')); ?>"><?php esc_html_e('WhatsApp Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_whatsapp')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_whatsapp')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_whatsapp); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_youtube')); ?>"><?php esc_html_e('Youtube Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_youtube')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_youtube')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_youtube); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_about_me_reddit')); ?>"><?php esc_html_e('Reddit Link:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_about_me_reddit')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_about_me_reddit')); ?>" type="text" value="<?php echo esc_attr($zolog_about_me_reddit); ?>">
        </p>
<?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;

        $instance['zolog_about_me_title'] = (!empty($new_instance['zolog_about_me_title'])) ? sanitize_text_field($new_instance['zolog_about_me_title']) : '';
        $instance['zolog_about_me_profile_image'] = (!empty($new_instance['zolog_about_me_profile_image'])) ? sanitize_text_field($new_instance['zolog_about_me_profile_image']) : '';
        $instance['zolog_about_me_name'] = (!empty($new_instance['zolog_about_me_name'])) ? sanitize_text_field($new_instance['zolog_about_me_name']) : '';
        $instance['zolog_about_me_sub_title'] = (!empty($new_instance['zolog_about_me_sub_title'])) ? sanitize_text_field($new_instance['zolog_about_me_sub_title']) : '';
        $instance['zolog_about_me_description'] = (!empty($new_instance['zolog_about_me_description'])) ? wp_kses_post($new_instance['zolog_about_me_description']) : '';
        if (!empty($new_instance['zolog_boxed_layout'])) {
            $instance['zolog_boxed_layout'] = ' checked="checked"';
        } else {
            $instance['zolog_boxed_layout'] = '';
        }
        $instance['zolog_about_me_theme'] = (!empty($new_instance['zolog_about_me_theme'])) ? sanitize_text_field($new_instance['zolog_about_me_theme']) : '1';
        $instance['zolog_about_me_email'] = (!empty($new_instance['zolog_about_me_email'])) ? sanitize_email($new_instance['zolog_about_me_email']) : '';
        $instance['zolog_about_me_twitter'] = (!empty($new_instance['zolog_about_me_twitter'])) ? esc_url($new_instance['zolog_about_me_twitter']) : '';
        $instance['zolog_about_me_linkedin'] = (!empty($new_instance['zolog_about_me_linkedin'])) ? esc_url($new_instance['zolog_about_me_linkedin']) : '';
        $instance['zolog_about_me_youtube'] = (!empty($new_instance['zolog_about_me_youtube'])) ? esc_url($new_instance['zolog_about_me_youtube']) : '';
        $instance['zolog_about_me_instagram'] = (!empty($new_instance['zolog_about_me_instagram'])) ? esc_url($new_instance['zolog_about_me_instagram']) : '';
        $instance['zolog_about_me_google_plus'] = (!empty($new_instance['zolog_about_me_google_plus'])) ? esc_url($new_instance['zolog_about_me_google_plus']) : '';
        $instance['zolog_about_me_facebook'] = (!empty($new_instance['zolog_about_me_facebook'])) ? esc_url($new_instance['zolog_about_me_facebook']) : '';
        $instance['zolog_about_me_pinterest'] = (!empty($new_instance['zolog_about_me_pinterest'])) ? esc_url($new_instance['zolog_about_me_pinterest']) : '';
        $instance['zolog_about_me_whatsapp'] = (!empty($new_instance['zolog_about_me_whatsapp'])) ? esc_url($new_instance['zolog_about_me_whatsapp']) : '';
        $instance['zolog_about_me_reddit'] = (!empty($new_instance['zolog_about_me_reddit'])) ? esc_url($new_instance['zolog_about_me_reddit']) : '';

        return $instance;
    }
}

function hs_register_about_me_widget()
{
    register_widget('hs_about_me_widget');
}
add_action('widgets_init', 'hs_register_about_me_widget');

add_action('admin_enqueue_scripts', 'admin_enqueue_zolog_about_me_script');
function admin_enqueue_zolog_about_me_script()
{
    wp_enqueue_script('media-upload');
    wp_enqueue_media();
    wp_enqueue_script('zolog_about_me_admin', get_template_directory_uri() . '/widgets/about-me/admin.js', array('jquery'));
}
