<?php
class hs_banner_widget extends WP_Widget
{
    function __construct()
    {
        add_action('wp_enqueue_scripts', array($this, 'hs_scripts'));
        parent::__construct(
            // widget ID
            'zolog_banner_widget',
            // widget name
            __('Zolog: Slider', 'zolog'),
            // widget description
            array('description' => __('Slider widget.', 'zolog'),)
        );
    }

    public function hs_scripts()
    {
        wp_enqueue_style('zolog-widget-banner', get_template_directory_uri() . '/widgets/banner/banner.css', array('zolog-style'), null);
    }

    public function widget($args, $instance)
    {
        extract($args, EXTR_SKIP);
        echo wp_kses_post($args['before_widget']);
        $instance['widget_id'] = $this->id;
        $banner_theme = !empty($instance['zolog_banner_theme']) ? $instance['zolog_banner_theme'] : '1';
        wp_add_inline_script('zolog-main-script', '
        jQuery(document).ready(function () {
            var preButton="<button type=\'button\' class=\'slick-prev pull-left\'><span class=\'dashicons dashicons-arrow-left-alt2\'></span></button>";
            var nextButton="<button type=\'button\' class=\'slick-next pull-right\'><span class=\'dashicons dashicons-arrow-right-alt2\'></span></button>";
            jQuery(".hs-' . esc_html($this->id) . '").slick({
              slidesToShow: 1,
              slidesToScroll: 1,
              autoplay: true,
              autoplaySpeed: 4000,
              lazyLoad: "ondemand",
              fade: true,
              cssEase: "linear",
              rtl: zolog_is_rtl.is_rtl,
              prevArrow: zolog_is_rtl.is_rtl ? nextButton : preButton,
              nextArrow: zolog_is_rtl.is_rtl ? preButton : nextButton,
            });
          });
        ');
        try {
?>
            <div class="zolog-banner-widget widget <?php echo !empty($instance['zolog_boxed_layout']) ? 'zolog-boxed' : ''; ?>">
                <?php get_template_part('/widgets/banner/theme/theme', $banner_theme, $instance); ?>
            </div>
        <?php

        } catch (Exception $ex) {
            echo '';
        }
        echo wp_kses_post($args['after_widget']);
    }

    public function form($instance)
    {
        $defaults = array(
            'zolog_banner_title' => '',
            'zolog_banner_description' => '',
            'zolog_banner_category' => '',
            'zolog_item_count' => '3',
            'zolog_boxed_layout' => '',
            'zolog_banner_theme' => '1',
            'zolog_banner_category_display' => 'show',
            'zolog_banner_meta_display' => 'show',

        );
        extract(wp_parse_args((array)$instance, $defaults));

        $boxed_layout = !empty($instance['zolog_boxed_layout']) ? $instance['zolog_boxed_layout'] : '';
        $zolog_banner_title = !empty($instance['zolog_banner_title']) ? $instance['zolog_banner_title'] : '';
        $zolog_banner_description = !empty($instance['zolog_banner_description']) ? $instance['zolog_banner_description'] : '';
        $zolog_banner_category_id = !empty($instance['zolog_banner_category']) ? $instance['zolog_banner_category'] : '';
        $item_count = !empty($instance['zolog_item_count']) ? $instance['zolog_item_count'] : '3';
        $zolog_banner_theme = !empty($instance['zolog_banner_theme']) ? $instance['zolog_banner_theme'] : '1';
        $zolog_banner_category_display = !empty($instance['zolog_banner_category_display']) ? $instance['zolog_banner_category_display'] : 'show';
        $zolog_banner_meta_display = !empty($instance['zolog_banner_meta_display']) ? $instance['zolog_banner_meta_display'] : 'show';
        ?>
        <p>
            <input type="checkbox" name="<?php echo esc_attr($this->get_field_name('zolog_boxed_layout')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_boxed_layout')); ?>" class="widefat" <?php echo esc_attr($boxed_layout); ?>>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_boxed_layout')); ?>"><?php esc_html_e('Boxed', 'zolog'); ?></label>
        </p>
        <h3><?php esc_html_e('Title', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_title')); ?>"><?php esc_html_e('Title:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_banner_title')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_banner_title')); ?>" type="text" value="<?php echo esc_attr($zolog_banner_title); ?>">
        </p>

        <h3><?php esc_html_e('Description', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_description')); ?>"><?php esc_html_e('Description:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_banner_description')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_banner_description')); ?>" type="text" value="<?php echo esc_attr($zolog_banner_description); ?>">
        </p>
        <h3><?php esc_html_e('Category', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_category')); ?>"><?php esc_html_e('Select Category', 'zolog'); ?></label>
            <select name="<?php echo esc_attr($this->get_field_name('zolog_banner_category')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_banner_category')); ?>" class="widefat">
                <?php
                $categories = get_categories(array(
                    'orderby' => 'name',
                    'order' => 'ASC'
                ));

                echo '<option value="" id="" >Select</option>';
                foreach ($categories as $category) {
                    $selected = '';
                    if ($zolog_banner_category_id == $category->term_id) {
                        $selected = ' selected="selected"';
                    }
                    echo '<option value="' . esc_attr($category->term_id) . '" id="' . esc_attr($category->term_id) . '" ' . selected("select3", $category->term_id, false) . esc_html($selected) . '>' . esc_html($category->name) . '</option>';
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_item_count')); ?>"><?php esc_html_e('Item Count', 'zolog'); ?></label>
            <input type="number" name="<?php echo esc_attr($this->get_field_name('zolog_item_count')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_item_count')); ?>" value="<?php echo esc_attr($item_count); ?>" min="1">
        </p>
        <h3><?php esc_html_e('Layout', 'zolog'); ?></h3>
        <p>
            <select name="<?php echo esc_attr($this->get_field_name('zolog_banner_theme')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_banner_theme')); ?>" class="widefat">
                <option value="1" id="theme1" <?php echo esc_html($zolog_banner_theme == '1' ? 'selected' : ''); ?>><?php esc_html_e('Theme One', 'zolog'); ?></option>
            </select>
        </p>
        <h3><?php esc_html_e('Category', 'zolog'); ?></h3>
        <div class="zolog-toggle">
            <div class="item">
                <input type="radio" <?php echo $zolog_banner_category_display == 'show' ? 'checked="checked"' : ''; ?> name="<?php echo esc_attr($this->get_field_name('zolog_banner_category_display')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_banner_category_display')); ?>-show" value="show">
                <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_category_display')); ?>-show"><?php echo esc_html__('Show', 'zolog'); ?></label><br>
            </div>
            <div class="item">
                <input type="radio" <?php echo $zolog_banner_category_display == 'hide' ? 'checked="checked"' : ''; ?> name="<?php echo esc_attr($this->get_field_name('zolog_banner_category_display')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_banner_category_display')); ?>-hide" value="hide">
                <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_category_display')); ?>-hide"><?php echo esc_html__('Hide', 'zolog'); ?></label><br>
            </div>
        </div>
        <h3><?php esc_html_e('Meta', 'zolog'); ?></h3>
        <div class="zolog-toggle">
            <div class="item">
                <input type="radio" <?php echo $zolog_banner_meta_display == 'show' ? 'checked="checked"' : ''; ?> name="<?php echo esc_attr($this->get_field_name('zolog_banner_meta_display')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_banner_meta_display')); ?>-show" value="show">
                <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_meta_display')); ?>-show"><?php echo esc_html__('Show', 'zolog'); ?></label><br>
            </div>
            <div class="item">
                <input type="radio" <?php echo $zolog_banner_meta_display == 'hide' ? 'checked="checked"' : ''; ?> name="<?php echo esc_attr($this->get_field_name('zolog_banner_meta_display')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_banner_meta_display')); ?>-hide" value="hide">
                <label for="<?php echo esc_attr($this->get_field_id('zolog_banner_meta_display')); ?>-hide"><?php echo esc_html__('Hide', 'zolog'); ?></label><br>
            </div>
        </div>


<?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;

        $instance['zolog_banner_title'] = (!empty($new_instance['zolog_banner_title'])) ? sanitize_text_field($new_instance['zolog_banner_title']) : '';
        $instance['zolog_banner_description'] = (!empty($new_instance['zolog_banner_description'])) ? sanitize_text_field($new_instance['zolog_banner_description']) : '';
        $instance['zolog_banner_category'] = (!empty($new_instance['zolog_banner_category'])) ? sanitize_text_field($new_instance['zolog_banner_category']) : '';
        if (!empty($new_instance['zolog_item_count'])) {
            $instance['zolog_item_count'] = sanitize_text_field($new_instance['zolog_item_count']);
        } else {
            $instance['zolog_item_count'] = '3';
        }
        if (!empty($new_instance['zolog_boxed_layout'])) {
            $instance['zolog_boxed_layout'] = ' checked="checked"';
        } else {
            $instance['zolog_boxed_layout'] = '';
        }
        $instance['zolog_banner_theme'] = (!empty($new_instance['zolog_banner_theme'])) ? sanitize_text_field($new_instance['zolog_banner_theme']) : '1';
        $instance['zolog_banner_category_display'] = (!empty($new_instance['zolog_banner_category_display'])) ? sanitize_text_field($new_instance['zolog_banner_category_display']) : 'show';
        $instance['zolog_banner_meta_display'] = (!empty($new_instance['zolog_banner_meta_display'])) ? sanitize_text_field($new_instance['zolog_banner_meta_display']) : 'show';

        return $instance;
    }
}

function hs_register_banner_widget()
{
    register_widget('hs_banner_widget');
}
add_action('widgets_init', 'hs_register_banner_widget');
