<?php
class hs_category_widget extends WP_Widget
{
    function __construct()
    {
        add_action('wp_enqueue_scripts', array($this, 'hs_scripts'));
        parent::__construct(
            // widget ID
            'zolog_category_widget',
            // widget name
            __('Zolog: Category', 'zolog'),
            // widget description
            array('description' => __('Category widget.', 'zolog'),)
        );
    }

    public function hs_scripts()
    {
        wp_enqueue_style('zolog-widget-category', get_template_directory_uri() . '/widgets/category/category.css', array('zolog-style'), null);
    }

    public function widget($args, $instance)
    {
        extract($args, EXTR_SKIP);
        echo wp_kses_post($args['before_widget']);
        $category_theme = !empty($instance['zolog_category_theme']) ? $instance['zolog_category_theme'] : '1';

        try {
?>
            <div class="zolog-category-widget widget <?php echo !empty($instance['zolog_boxed_layout']) ? 'zolog-boxed' : ''; ?>">
                <?php get_template_part('/widgets/category/theme/theme', $category_theme, $instance); ?>
            </div>
        <?php

        } catch (Exception $ex) {
            echo '';
        }
        echo wp_kses_post($args['after_widget']);
    }

    public function form($instance)
    {
        $defaults = array(
            'zolog_category_title' => '',
            'zolog_category_category' => '',
            'zolog_item_count' => '3',
            'zolog_boxed_layout' => '',
            'zolog_category_theme' => '1',

        );
        extract(wp_parse_args((array)$instance, $defaults));

        $boxed_layout = !empty($instance['zolog_boxed_layout']) ? $instance['zolog_boxed_layout'] : '';
        $zolog_category_title = !empty($instance['zolog_category_title']) ? $instance['zolog_category_title'] : '';
        $zolog_category_category_id = !empty($instance['zolog_category_category']) ? $instance['zolog_category_category'] : '';
        $item_count = !empty($instance['zolog_item_count']) ? $instance['zolog_item_count'] : '3';
        $zolog_category_theme = !empty($instance['zolog_category_theme']) ? $instance['zolog_category_theme'] : '1';
        ?>
        <p>
            <input type="checkbox" name="<?php echo esc_attr($this->get_field_name('zolog_boxed_layout')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_boxed_layout')); ?>" class="widefat" <?php echo esc_attr($boxed_layout); ?>>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_boxed_layout')); ?>"><?php esc_html_e('Boxed', 'zolog'); ?></label>
        </p>
        <h3><?php esc_html_e('Title', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_category_title')); ?>"><?php esc_html_e('Title:', 'zolog'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('zolog_category_title')); ?>" name="<?php echo esc_attr($this->get_field_name('zolog_category_title')); ?>" type="text" value="<?php echo esc_attr($zolog_category_title); ?>">
        </p>
        <h3><?php esc_html_e('Category', 'zolog'); ?></h3>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_category_category')); ?>"><?php esc_html_e('Select Category', 'zolog'); ?></label>
            <select name="<?php echo esc_attr($this->get_field_name('zolog_category_category')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_category_category')); ?>" class="widefat">
                <?php
                $categories = get_categories(array(
                    'orderby' => 'name',
                    'order' => 'ASC'
                ));

                echo '<option value="" id="" >Select</option>';
                foreach ($categories as $category) {
                    $selected = '';
                    if ($zolog_category_category_id == $category->term_id) {
                        $selected = ' selected="selected"';
                    }
                    echo '<option value="' . esc_attr($category->term_id) . '" id="' . esc_attr($category->term_id) . '" ' . selected("select3", $category->term_id, false) . esc_html($selected) . '>' . esc_html($category->name) . '</option>';
                } ?>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zolog_item_count')); ?>"><?php esc_html_e('Item Count', 'zolog'); ?></label>
            <input type="number" name="<?php echo esc_attr($this->get_field_name('zolog_item_count')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_item_count')); ?>" value="<?php echo esc_attr($item_count); ?>" min="1">
        </p>
        <h3><?php esc_html_e('Layout', 'zolog'); ?></h3>
        <p>
            <select name="<?php echo esc_attr($this->get_field_name('zolog_category_theme')); ?>" id="<?php echo esc_attr($this->get_field_id('zolog_category_theme')); ?>" class="widefat">
                <option value="1" id="theme1" <?php echo esc_html($zolog_category_theme == '1' ? 'selected' : ''); ?>><?php esc_html_e('Theme One', 'zolog'); ?></option>
                <option value="2" id="theme2" <?php echo esc_html($zolog_category_theme == '2' ? 'selected' : ''); ?>><?php esc_html_e('Theme Two', 'zolog'); ?></option>
                <option value="3" id="theme3" <?php echo esc_html($zolog_category_theme == '3' ? 'selected' : ''); ?>><?php esc_html_e('Theme Three', 'zolog'); ?></option>
                <option value="4" id="theme4" <?php echo esc_html($zolog_category_theme == '4' ? 'selected' : ''); ?>><?php esc_html_e('Theme Four', 'zolog'); ?></option>
            </select>
        </p>
<?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;

        $instance['zolog_category_title'] = (!empty($new_instance['zolog_category_title'])) ? sanitize_text_field($new_instance['zolog_category_title']) : '';
        $instance['zolog_category_category'] = (!empty($new_instance['zolog_category_category'])) ? sanitize_text_field($new_instance['zolog_category_category']) : '';

        if (!empty($new_instance['zolog_item_count'])) {
            $instance['zolog_item_count'] = sanitize_text_field($new_instance['zolog_item_count']);
        } else {
            $instance['zolog_item_count'] = '3';
        }

        if (!empty($new_instance['zolog_boxed_layout'])) {
            $instance['zolog_boxed_layout'] = ' checked="checked"';
        } else {
            $instance['zolog_boxed_layout'] = '';
        }
        $instance['zolog_category_theme'] = (!empty($new_instance['zolog_category_theme'])) ? sanitize_text_field($new_instance['zolog_category_theme']) : '1';

        return $instance;
    }
}

function hs_register_category_widget()
{
    register_widget('hs_category_widget');
}
add_action('widgets_init', 'hs_register_category_widget');
